@@ -19,7 +19,7 @@ require('font-awesome/css/font-awesome.min.css');
  * The main entry point for the application.
  */
 function main() {
-  var app = window.lab = require('@jupyterlab/application').JupyterLab;
+  var JupyterLab = require('@jupyterlab/application').JupyterLab;
 
   // Get the disabled extensions.
   var disabled = { patterns: [], matches: [] };
@@ -149,14 +149,19 @@ function main() {
   // eslint-disable-next-line semi
   {{/each}}
 
-  var lab = new app({
+  var lab = new JupyterLab({
     mimeExtensions: mimeExtensions,
     disabled: disabled,
-    deferred: deferred,
+    deferred: deferred
   });
   register.forEach(function(item) { lab.registerPluginModule(item); });
   lab.start({ ignorePlugins: ignorePlugins });
 
+  // Expose global lab instance when in dev mode.
+  if ((PageConfig.getOption('devMode') || '').toLowerCase() === 'true') {
+    window.lab = lab;
+  }
+
   // Handle a selenium test.
   var seleniumTest = PageConfig.getOption('seleniumTest');
   if (seleniumTest.toLowerCase() === 'true') {
